summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qchecklistitem_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qchecklistitem_imp.h')
-rw-r--r--kjsembed/qtbindings/qchecklistitem_imp.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kjsembed/qtbindings/qchecklistitem_imp.h b/kjsembed/qtbindings/qchecklistitem_imp.h
index a24c316f..f9dca63f 100644
--- a/kjsembed/qtbindings/qchecklistitem_imp.h
+++ b/kjsembed/qtbindings/qchecklistitem_imp.h
@@ -10,7 +10,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
#include <kjsembed/jsbindingbase.h>
-class TTQCheckListItem;
+class TQCheckListItem;
/**
* Namespace containing the KJSEmbed library.
@@ -26,7 +26,7 @@ namespace Bindings {
};
}
/**
* Wrapper class for TTQCheckListItem methods.
*
* @author Richard Moore, rich@kde.org
*/
@@ -72,7 +72,7 @@ public:
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static TTQCheckListItem *toTQCheckListItem( KJS::Object &object );
+ static TQCheckListItem *toTQCheckListItem( KJS::Object &object );
//
// Constructors implemented by this class.
@@ -123,7 +123,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TTQCheckListItem *instance; // Temp
+ TQCheckListItem *instance; // Temp
int id;
bool cons;
};
@@ -26,7 +26,7 @@ namespace Bindings {
}
/**
- * Wrapper class for TTQCheckListItem methods.
+ * Wrapper class for TQCheckListItem methods.
*
* @author Richard Moore, rich@kde.org